package productlogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetTagsLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetTagsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetTagsLogic {
	return &GetTagsLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// GetTags 取得 tags
func (l *GetTagsLogic) GetTags(in *product.TagsReq) (*product.Tags, error) {
	tag, err := l.svcCtx.TagsUseCase.GetByID(l.ctx, in.GetId())
	if err != nil {
		return nil, err
	}

	result := &product.Tags{Id: tag.ID.Hex(),
		Types:     int32(tag.Types),
		Name:      tag.Name,
		ShowType:  int64(tag.ShowType),
		UpdateAt:  tag.UpdatedAt,
		CreatedAt: tag.CreatedAt,
	}
	if tag.Cover != nil {
		result.Cover = *tag.Cover
	}

	return result, nil
}
