package productlogic

import (
	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"
	"code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/entity"
	domain "code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/product"
	"code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/usecase"
	"context"
	"github.com/zeromicro/go-zero/core/logx"
)

type ListTagsLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewListTagsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ListTagsLogic {
	return &ListTagsLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// ListTags 建立 tags
func (l *ListTagsLogic) ListTags(in *product.ListTagsReq) (*product.ListTagsResp, error) {
	tags := make([]*entity.Tags, 0)
	var err error
	var total int64

	if len(in.GetIds()) > 0 {
		tags, err = l.svcCtx.TagsUseCase.GetByIDs(l.ctx, in.GetIds())
		if err != nil {
			return nil, err
		}
		total = int64(len(tags))
	} else {
		q := usecase.TagQueryParams{
			PageSize:  in.GetPageSize(),
			PageIndex: in.GetPageIndex(),
		}
		if in.Name != nil {
			q.Name = in.Name
		}
		if in.Types != nil {
			t, err := safeItemType(*in.Types)
			if err != nil {
				return nil, err
			}
			q.Types = &t
		}
		if in.ShowType != nil {
			st := domain.ShowType(*in.ShowType)
			q.ShowType = &st
		}

		tags, total, err = l.svcCtx.TagsUseCase.List(l.ctx, q)
		if err != nil {
			return nil, err
		}
	}

	result := make([]*product.Tags, 0, len(tags))
	for _, tag := range tags {
		r := &product.Tags{Id: tag.ID.Hex(),
			Types:     int32(tag.Types),
			Name:      tag.Name,
			ShowType:  int64(tag.ShowType),
			UpdateAt:  tag.UpdatedAt,
			CreatedAt: tag.CreatedAt,
		}
		if tag.Cover != nil {
			r.Cover = *tag.Cover
		}

		result = append(result, r)
	}

	return &product.ListTagsResp{
		Total: total,
		Data:  result,
	}, nil
}
