package productlogic

import (
	domain "code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/product"
	"code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/usecase"
	"context"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type ModifyTagsLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewModifyTagsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ModifyTagsLogic {
	return &ModifyTagsLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// ModifyTags 修改 tags
func (l *ModifyTagsLogic) ModifyTags(in *product.ModifyTagsReq) (*product.OKResp, error) {
	var params usecase.TagModifyParams

	// 處理 types（int32 → ItemType）
	if in.Types != nil {
		t, err := safeItemType(*in.Types)
		if err != nil {
			return nil, err
		}
		params.Types = &t
	}

	// 處理 name
	if in.Name != nil {
		params.Name = in.Name
	}

	// 處理 show_type（int64 → ShowType）
	if in.ShowType != nil {
		st := domain.ShowType(*in.ShowType)
		params.ShowType = &st
	}

	// 處理 cover
	if in.Cover != nil {
		params.Cover = in.Cover
	}

	// 執行更新
	err := l.svcCtx.TagsUseCase.Update(l.ctx, in.GetId(), params)
	if err != nil {
		return nil, err
	}

	return &product.OKResp{}, nil
}
